/*
 * example: sendok \" VRML 2.0 Exporter\" 1 15
 * sendto sends a WM_COMMAND message to a window with a
 * given name. If you use it to \"batch\" drive a dialogbox
 * you have to use the dialog title to identify the dialog box
 * If the title contains blanks - you must quote the title
 * Use the -l option to list all windows (watch out for blanks in title!)
 * The spawn version must be used, if you want to send the message
 * to a modal dialogbox. Just put the call to sendok IN FRONT of the dialogbox call 
 * and add a time in seconds to wait for the dialogbox to appear.
 * The most used Command ID's are:
 * IDOK: ID=1,IDCANCEL: ID=2,IDABORT:ID=3,IDRETRY:ID=4, IDIGNORE:ID=5
 * IDYES:ID=6,IDNO:ID=7,IDCLOSE:ID=8,IDHELP:ID=9
 * FREEWARE, V 1.0: Horst G. Brueckner, netnice, hb@netnice.com\n");
 */
#include <windows.h>
#include <stdio.h>
#include <process.h>
#include <time.h>

BOOL CALLBACK EnumWindowsProc (HWND hwnd, DWORD lParam);

void main (int argc, char **argv)
{
   HWND h;
   time_t now, then;
   int    seconds;
   char szNewCommandline[256];

/* display usage */
   if (argc == 1)
   {
      printf ("usage: sendok <WindowTitle> <ID>   -- or\n");
      printf ("usage: sendok <WindowTitle> <ID> <seconds>  -- or\n");
      printf ("usage: sendok -l\n");
      printf ("example: doscommand \"sendok \" VRML 2.0 Exporter\" 1 15\"\n");
      printf ("         exportfile \"hugo.wrl\" #noprompt\n");
      printf ("sendok sends a WM_COMMAND message to a window with a\n");
      printf ("given name. If you use it to \"batch\" drive a dialogbox\n");
      printf ("you have to use the dialog title to identify the dialog box\n");
      printf ("If the title contains blanks - you must quote the title\n");
      printf ("Use the -l option to list all windows (watch out for blanks in title!)\n");
      printf ("Put the call of sendok in front of the dialogboxcall and add a time\n");
      printf ("in seconds on the commandline. Sendok will start a subprocess which\n");
      printf ("waits for the dialogbox to come up\n");
      printf ("\nThe most used Command ID's are:\n");
      printf ("IDOK: ID=1");
      printf ("IDCANCEL: ID=2");
      printf ("IDABORT:ID=3");
      printf ("IDRETRY:ID=4\n");
      printf ("IDIGNORE:ID=5");
      printf ("IDYES:ID=6");
      printf ("IDNO:ID=7");
      printf ("IDCLOSE:ID=8");
      printf ("IDHELP:ID=9\n");
      printf ("\nFREEWARE, V 1.0: Horst G. Brueckner, netnice, hb@netnice.com\n");
   } 
/* display known windows in a list */
   else if (argc == 2)
   {
      EnumWindows (EnumWindowsProc, 0);
   }
/* do the real work */
   else if (argc == 3)
   {
/*    try to find window with given title */
      h = FindWindow (NULL, argv[1]);
      if (h != NULL)
      {
         PostMessage (h, WM_COMMAND, atoi (argv[2]), 0);
      }
      else
      {
         printf ("Window: \"%s\" not found\n");
	      exit (1);
      }
   }
/* spawn and wait for a window to appear then do work */
   else if (argc == 4)
   {
/*    requote the window title */
      sprintf (szNewCommandline, "\"%s\"", argv[1]);
      spawnl (_P_NOWAIT, argv[0], argv[0], szNewCommandline, argv[2], argv[3], "spawn", NULL);
      exit (0);
   }
/* we are a subprocess wait for windows for the given time and then send message */
   else if (argc == 5)
   {
      time (&now);
      seconds = atoi (argv[3]);
      while (TRUE)
      {
/*       try to find window with given title */
         h = FindWindow (NULL, argv[1]);
         if (h != NULL)
         {
            PostMessage (h, WM_COMMAND, atoi (argv[2]), 0);
            break;
         }
         time (&then);
         if (then - now > seconds)
         {
            break;
         }
      }
   }
	exit (0);
}

BOOL CALLBACK EnumWindowsProc (HWND hwnd, DWORD lParam)
{
    char              buf[512];


    if (GetWindowText(hwnd, buf, sizeof(buf) )) 
    {
      printf ("<%s>\n", buf);
    }
    // continue the enumeration
    return TRUE;
}

